
/*

  Code modified from original source here: 
  https://github.com/sparkfun/SparkFun_BNO08x_Arduino_Library/blob/main/examples/Example_13_EulerAngles/Example_13_EulerAngles.ino
  Using the BNO08x IMU

  This example shows how to output the Euler angles: roll, pitch and yaw.
  The yaw (compass heading) is tilt-compensated, which is nice.
  https://en.wikipedia.org/wiki/Conversion_between_quaternions_and_Euler_angles
  https://github.com/sparkfun/SparkFun_MPU-9250-DMP_Arduino_Library/issues/5#issuecomment-306509440
*/

#include <Wire.h>

#include "SparkFun_BNO08x_Arduino_Library.h"  
BNO08x myIMU;


#define BNO08X_INT  -1
#define BNO08X_RST  -1

#define BNO08X_ADDR 0x4A 

void IMUsetup() {
  if (myIMU.begin(BNO08X_ADDR, Wire, BNO08X_INT, BNO08X_RST) == false) {
    Serial.println("BNO08x not detected at default I2C address. Check your jumpers and the hookup guide. Freezing...");
    while (1)
      ;
  }
  Serial.println("BNO08x found!");
  setReports();
  Serial.println("Reading events");
  delay(100);
}

// Here is where you define the sensor outputs you want to receive
void setReports(void) {
  Serial.println("Setting desired reports");
  if (myIMU.enableRotationVector() == true) {
    Serial.println(F("Rotation vector enabled"));
    Serial.println(F("Output in form roll, pitch, yaw"));
  } else {
    Serial.println("Could not enable rotation vector");
  }
}

void IMUloop() {
  delay(10);

  if (myIMU.wasReset()) {
    Serial.print("sensor was reset ");
    setReports();
  }

  // Has a new event come in on the Sensor Hub Bus?
  if (myIMU.getSensorEvent() == true) {

    // is it the correct sensor data we want?
    if (myIMU.getSensorEventID() == SENSOR_REPORTID_ROTATION_VECTOR) {

    float roll = (myIMU.getRoll()) * 180.0 / PI; // Convert roll to degrees
    float pitch = (myIMU.getPitch()) * 180.0 / PI; // Convert pitch to degrees
    float yaw = (myIMU.getYaw()) * 180.0 / PI; // Convert yaw / heading to degrees

    OSCBundle imubndl;
    imubndl.add("/pitch").add(pitch);
    imubndl.add("/roll").add(roll);
    imubndl.add("/yaw").add(yaw);
    Udp.beginPacket(outIp, 6666);

    imubndl.send(Udp); // send the bytes to the SLIP stream
    Udp.endPacket(); // mark the end of the OSC Packet
    imubndl.empty(); // empty the bundle to free room for a new one
    }
  }
}