/****
code for sending osc messages over wifi modified from this source:
https://github.com/CNMAT/OSC/blob/master/examples/ESP8266sendMessage/ESP8266sendMessage.ino
***/

#include "Wire.h"
#include "SPI.h"

#include <WiFi.h>
#include <WiFiUdp.h>
#include <OSCMessage.h>
#include <OSCBundle.h>
#include <OSCData.h>

const int led0 = 44;
const int led1 = 7;
const int led2 = 8;
const int led3 = 9;

int b0, b1, b2, b3 = 0;
int h0, h1, h2, h3 = 0;


/*********************************************
  WIFI SETUP
*********************************************/

char ssid[] = "Moosenet";        
char pass[] = "tinylilguy5";    

WiFiUDP Udp;                                // A UDP instance to let us send and receive packets over UDP
const unsigned int outPort = 9999;          // remote port to receive OSC
const unsigned int localPort = 8888;        // local port to listen for UDP packets (here's where we send the packets)

                                      
const IPAddress outIp(192,168,68,60);      // moosenet ip
IPAddress local_IP(192, 168, 1, 184); // Set your Static IP address
IPAddress gateway(192, 168, 1, 1); // Set your Gateway IP address

IPAddress subnet(255, 255, 0, 0);
IPAddress primaryDNS(8, 8, 8, 8);   // optional
IPAddress secondaryDNS(8, 8, 4, 4); // optional

/*********************************************
*********************************************/


void setup() {
  Serial.begin(115200);
  delay(100);
  Wire.begin();

  if (!WiFi.config(local_IP, gateway, subnet, primaryDNS, secondaryDNS)) {
  Serial.println("STA Failed to configure");}
  
  WiFi.begin(ssid, pass);
  while(WiFi.status() != WL_CONNECTED) {delay(500);} //wait for wifi connection
  Udp.begin(localPort); // start UDP

  ledcAttachPin(led0, 0);
  ledcAttachPin(led1, 1); // assign a led pins to a channel
  ledcAttachPin(led2, 2);
  ledcAttachPin(led3, 3);
  for (int i = 0; i<4; i++){
    ledcSetup(i, 4000, 8); // 12 kHz PWM, 8-bit resolution
  }
  for (int i = 0; i<4; i++){
      ledcWrite(i, 255); // start brightness
  }
    IMUsetup();
}

void loop() {

  h0 = analogRead(1);
  h1 = analogRead(2);
  h2 = analogRead(3);
  h3 = analogRead(4);

  b0 = 255- (h0* 255/2000);
  ledcWrite(0, b0);
  b1 = 255- (h1 * 255/2000);
  ledcWrite(1, b1);
  b2 = 255- (h2 * 255/2000);
  ledcWrite(2, b2);
  b3 = 255- (h3 * 255/2000);
  ledcWrite(3, b3);

    OSCBundle hallbndl;
    hallbndl.add("/h0").add(h0);
    hallbndl.add("/h1").add(h1);
    hallbndl.add("/h2").add(h2);
    hallbndl.add("/h3").add(h3);
    Udp.beginPacket(outIp, 6666);

    hallbndl.send(Udp); // send the bytes to the SLIP stream
    Udp.endPacket(); // mark the end of the OSC Packet
    hallbndl.empty(); // empty the bundle to free room for a new one
  
    IMUloop();

}